@@ -26,7 +26,6 @@
 #endif
 
 Display *display;
-int display_fd;
 char *displayname;
 NPWindow windata;
 int flags;
@@ -394,11 +393,6 @@ static void handle_app(int pid)
      int swallow_done = 0;
      int status;
      int tmp;
-     fd_set fds;
-     struct timeval tv;
-
-     tv.tv_sec = 0;
-     tv.tv_usec = SWALLOW_WAIT_TIME;
 
      if ((flags & H_SWALLOW) || (flags & H_EVENT_SWALLOW))
      {
@@ -419,13 +413,8 @@ static void handle_app(int pid)
 		    swallow_done = event_swallow();
 
 	       if (swallow_done) break;
-	       
-	       FD_ZERO(&fds);
-	       FD_SET(display_fd, &fds);
 
-	       D("select()\n");
-	       if (select(display_fd+1, &fds, NULL, NULL, &tv) == -1)
-		    exit(1);
+	       usleep(SWALLOW_WAIT_TIME);
 	  }
 	  end_swallow();
      }
@@ -532,7 +521,6 @@ int main(int argc, char **argv)
 	       if (!display)
 	       {
 		    display = XOpenDisplay(displayname);
-		    display_fd = ConnectionNumber(display);
 	       }
 
 	       if (init_swallow())
