@@ -211,7 +211,8 @@ static void run(NPP instance, const char *file)
 	  my_putenv(buffer, &offset, "controller", controller_fname);
 
      for (i = 0; i < THIS->num_arguments; i++)
-	  my_putenv(buffer, &offset, THIS->args[i].var, THIS->args[i].value);
+	  if (THIS->args[i].value)
+	       my_putenv(buffer, &offset, THIS->args[i].var, THIS->args[i].value);
 
      execlp(helper_fname, helper_fname, buffer, THIS->command, NULL);
 
@@ -299,11 +300,10 @@ static void filter_previous_handler()
 /*****************************************************************************
  * Match a word to an option of the type swallow(name).
  *****************************************************************************/
-static char *gobble_fct(char *x, char *option, command_t *c, int flag)
+static char *gobble_winname(char *x, char *option, command_t *c)
 {
      char *end;
-     
-     c->flags |= flag;
+ 
      x += strlen(option);
      while (isspace(*x)) x++;
      if (*x != '(')
@@ -363,18 +363,20 @@ static int parse_options(char **x, command_t *commandp)
 	  }
 	  if (gobble(*x, "swallow"))
 	  {
-	       if ((*x = gobble_fct(*x, "swallow", commandp, H_SWALLOW)))
+	       commandp->flags |= H_SWALLOW;
+	       if ((*x = gobble_winname(*x, "swallow", commandp)))
 		    return 1;
 	  }
 	  if (gobble(*x, "event_swallow"))
 	  {
-	       if ((*x = gobble_fct(*x, "event_swallow", commandp, H_EVENT_SWALLOW)))
+	       commandp->flags |= H_EVENT_SWALLOW;
+	       if ((*x = gobble_winname(*x, "event_swallow", commandp)))
 		    return 1;
 	  }
 	  if (gobble(*x, "controls"))
 	  {
 	       commandp->flags |= H_CONTROLS | H_SWALLOW | H_FILL;
-	       commandp->winname = "mozplugger-controller";
+	       commandp->winname = strdup("mozplugger-controller");
 	       *x += 8;
 	       return 1;
 	  }
@@ -432,7 +434,7 @@ static void read_config(FILE *f)
 
 	       D("Parsing %s\n", x);
 
-	       while (*x!=':' && *x)
+	       while (*x != ':' && *x)
 	       {
 		    switch(*x) {
 		    case ',':
@@ -449,7 +451,7 @@ static void read_config(FILE *f)
 			 }
 		    }
 	       }
-	       if (*x==':')
+	       if (*x == ':')
 	       {
 		    x++;
 		    while (isspace(*x)) x++;
@@ -468,11 +470,12 @@ static void read_config(FILE *f)
 
 		    (*commandp)->cmd = strdup(x);
 	       } else {
-		    D("No colon? (%s)\n",x);
+		    D("No column? (%s)\n", x);
 	       }
 
 	       if (!(*commandp)->cmd)
 	       {
+		    free((*commandp)->winname);
 		    free(*commandp);
 		    *commandp = NULL;
 		    continue;
@@ -881,12 +884,12 @@ NPError NPP_New(NPMIMEType pluginType,
 	       src_attr = e;
 	  }
 	  /* copy the option to put it into the environement later */
-	  if ((THIS->args[e].var = (char *)malloc(strlen(argn[e]) + 5)))
-	  {
-	       memcpy(THIS->args[e].var, "VAR_", 4);
-	       memcpy(THIS->args[e].var+4, argn[e], strlen(argn[e])+1);
-	       THIS->args[e].value = strdup(argv[e]);
-	  }
+	  D("VAR_%s=%s\n", argn[e], argv[e]);
+	  if (!(THIS->args[e].var = (char *)malloc(strlen(argn[e]) + 5)))
+	       return NPERR_OUT_OF_MEMORY_ERROR;
+	  memcpy(THIS->args[e].var, "VAR_", 4);
+	  memcpy(THIS->args[e].var+4, argn[e], strlen(argn[e])+1);
+	  THIS->args[e].value = argv[e] ? strdup(argv[e]) : NULL;
      }
 
      /* Special case for quicktime. If there's an href attribute, we 
